@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MultipartMessageParser.cpp 2475 2007-07-01 05:35:29Z svn $
+ * $Id: MultipartMessageParser.cpp 2614 2007-10-28 13:17:35Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -37,8 +37,6 @@
 
 using namespace std;
 
-#define AS_CONTENT(pointer)         reinterpret_cast<content_t *>(pointer)
-
 #undef DUMP_INPUT_AND_THROW
 #ifdef DEBUG_MultipartMessageParser
 #define DUMP_INPUT_AND_THROW(message) dump_input(buffer_); THROW(message)
@@ -68,6 +66,8 @@ MultipartMessageParser<R, W>::READ_TIMEOUT_SEC      = REQ_READ_TIMEOUT_SEC;
 template<class R, class W> const char
 MultipartMessageParser<R, W>::CR_LF[]               = "\r\n";
 template<class R, class W> const char
+MultipartMessageParser<R, W>::CR_LF_CR_LF[]         = "\r\n\r\n";
+template<class R, class W> const char
 MultipartMessageParser<R, W>::CONTENT_TYPE[]        = "Content-Type: ";
 template<class R, class W> const char
 MultipartMessageParser<R, W>::CONTENT_DISPOSITION[] = "Content-Disposition: ";
@@ -470,6 +470,19 @@ const char *MultipartMessageParser<R, W>::skip_line(const char *input_start)
     return start + strlen(CR_LF);
 }
 
+template<class R, class W>
+const char *MultipartMessageParser<R, W>::skip_header(const char *input_start)
+{
+    const char *start = strstr(input_start, CR_LF_CR_LF);
+
+    TRACE_FUNC;
+
+    if (start == NULL) {
+        DUMP_INPUT_AND_THROW(MESSAGE_RFC1867_FORMAT_INVALID);
+    }
+
+    return start + strlen(CR_LF_CR_LF);
+}
 
 template<class R, class W>
 void MultipartMessageParser<R, W>::write_text(char **text, apr_size_t *text_length,
