@@ -106,6 +106,9 @@ namespace UploaderConfig
 
             indexTmplPathTextBox.Validating +=
                 new CancelEventHandler((new FilePathValidator(indexTmplPathLabel, errorProvider)).validate);
+            infoTmplPathTextBox.Validating +=
+                new CancelEventHandler((new FilePathValidator(infoTmplPathLabel, errorProvider)).validate);
+
             progressTmplPathTextBox.Validating +=
                 new CancelEventHandler((new FilePathValidator(progressTmplPathLabel, errorProvider)).validate);
             downloadTmplPathTextBox.Validating +=
@@ -174,6 +177,20 @@ namespace UploaderConfig
             ValidateChildren();
         }
 
+        private void infoTmplPathButton_Click(object sender, EventArgs e)
+        {
+            string file_path = chooseTemplateFile(infoTmplPathLabel,
+                infoTmplPathTextBox.Text);
+
+            if (file_path == null) {
+                return;
+            }
+
+            uploaderConfig.downloadTmplPath = file_path;
+            uploaderConfigBindingSource.ResetBindings(false);
+            ValidateChildren();
+        }
+
         private void progressTmplPathButton_Click(object sender, EventArgs e)
         {
             string file_path = chooseTemplateFile(progressTmplPathLabel,
